@@ -3,7 +3,7 @@ from functools import partial
 
 #####################
 
-def cur(session, query, **kargs):
+def query(session, query, **kargs):
     generated_query = generate_query(query, **kargs) 
     return partial(wr.athena.read_sql_query,
                    database=kargs.get('db'),
