@@ -1,5 +1,5 @@
 from jsonpath_ng import parse
-import ec2_paginate
+from .paginate import ec2_paginate
 
 #####################################
 
