@@ -1,4 +1,3 @@
-import json
 import boto3
 from jsonpath_ng import jsonpath, parse
 
@@ -28,13 +27,15 @@ def found(args,d2):
 
 class paginate():
     def __init__(self, session, **kargs):
-        self.response = []
+        self.json = []
         self.session = session
         for page in self.session.client(kargs.get('service')).get_paginator(kargs.get('ep')).paginate():
             self.response = [fields(i.value, kargs) for i in self.jsonpath_expression().find(page) if found(kargs, i.value)]
+        self.df = pd.json_normalize(self.json)
+
             
     def __str__(self):
-        return json.dumps(self.response)
+        return json.dumps(self.json)
 
 #####################################
 
